# Product Catalog

Name | Price | Category | In Stock
--- | --- | --- | ---
Wireless Mouse | $29.99 | Electronics | Yes
USB-C Hub | $49.95 | Electronics | Yes
Mechanical Keyboard | $89.99 | Electronics | No
Desk Lamp | $34.50 | Home Office | Yes
Monitor Stand | $45.00 | Home Office | Yes
Ergonomic Chair | $299.99 | Home Office | No
Notebook Pack | $12.99 | Stationery | Yes
Gel Pen Set | $8.49 | Stationery | Yes
Sticky Notes | $5.99 | Stationery | Yes
Webcam HD | $59.99 | Electronics | Yes